/***************************************************************************
                             queryresultsmenu.h
                             -------------------
    begin                : Fri Jan 28 2005
    copyright            : (C) 2005 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef QUERYRESULTSMENU_H
#define QUERYRESULTSMENU_H

#include <qpopupmenu.h>
#include <qlistview.h>

/**
 * Provides a popup-menu for list views containing query results.
 * The popup menu contains commands for copying field text out of items and
 * for removing items.
 * This class assumes a certain ordering of the list columns. If an owner
 * object uses a different configuration, it needs to call setColumns() after
 * constructing the object.
 * @author Elad Lahav
 */
class QueryResultsMenu : public QPopupMenu
{
	Q_OBJECT
	
public:
    QueryResultsMenu(QWidget* pParent = 0, const char* szName = 0);
    ~QueryResultsMenu();
	
	/** This value should be used with setColumns() to indicate a column
		that does not appear in the owner list. */
	enum { Unused = -2 };
	
	void setColumns(int, int, int, int);
	
public slots:		
	void slotShow(QListViewItem*, const QPoint&, int nCol);
	
signals:
	/** 
	 * Indicates a "Copy [Field]" menu item has been selected. 
	 * @param	pItem	The item for which the menu was displayed
	 * @param	int		The requested column
	 */
	void copy(QListViewItem*, int);
	
	/** 
	 * Indicates the "Remove Item" menu item has been selected. 
	 * @param	pItem	The item for which the menu was displayed
	 */
	void remove(QListViewItem*);
	
private:
	/** The list column that contains the file path field. */
	int m_nFileCol;
	
	/** The list column that contains the function name field. */
	int m_nFuncCol;
	
	/** The list column that contains the line number field. */
	int m_nLineCol;
	
	/** The list column that contains the line's text. */
	int m_nTextCol;
	
	/** The "Copy File" menu item identifier. */
	int m_nCopyFileId;
	
	/** The "Copy Function" menu item identifier. */
	int m_nCopyFuncId;
	
	/** The "Copy Line" menu item identifier. */
	int m_nCopyLineId;
	
	/** The "Copy Text" menu item identifier. */
	int m_nCopyTextId;
	
	/** The "Remove Item" menu item identifier. */
	int m_nRemItemId;
	
	/** The item for which the popup menu is provided (cannot be NULL). */
	QListViewItem* m_pItem;
	
private slots:
	void slotActivated(int);
};

#endif
